Package: miRNApath
Type: Package
Title: miRNApath: Pathway Enrichment for miRNA Expression Data
Version: 1.72.0
Author: James M. Ward <jmw86069@gmail.com> with contributions
   from Yunling Shi, Cindy Richards, John P. Cogswell
Maintainer: James M. Ward <jmw86069@gmail.com>
Description: This package provides pathway enrichment techniques
   for miRNA expression data. Specifically, the set of
   methods handles the many-to-many relationship between miRNAs
   and the multiple genes they are predicted to target (and thus
   affect.)  It also handles the gene-to-pathway relationships
   separately. Both steps are designed to preserve the additive
   effects of miRNAs on genes, many miRNAs affecting one gene,
   one miRNA affecting multiple genes, or many miRNAs affecting
   many genes.
License: LGPL-2.1
biocViews: Annotation, Pathways, DifferentialExpression,
        NetworkEnrichment, miRNA
Depends: methods, R(>= 2.7.0)
LazyLoad: Yes
git_url: https://git.bioconductor.org/packages/miRNApath
git_branch: RELEASE_3_23
git_last_commit: b18488b
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:17:50 UTC; biocbuild
